/*=========================================================================

  xmlCFD - an implementation of a proposed XML-based geometry /
  condition description format for CFD

  Copyright (c) 2010 Takuya OSHIMA <oshima@eng.niigata-u.ac.jp>.
  All rights reserved.
  See License.txt for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

#include "vtkXMLDataParser.h"
#include "vtkSetGet.h"

#include <vtkstd/vector>

class xmlBoundaries;
class xmlField;

class vtkPolyData;
class vtkStdString;
class vtkXMLDataElement;

class xmlCFD: public vtkXMLDataParser
{
public:
  vtkTypeRevisionMacro(xmlCFD, vtkXMLDataParser);
  void PrintSelf(ostream&, vtkIndent);

  static xmlCFD *New();

  int Parse();

  void SetFileName(const char *);

  xmlBoundaries &GetBoundaries() { return *Boundaries; }

protected:
  xmlCFD();
  ~xmlCFD();

private:
  int ParseName(vtkXMLDataElement *);
  vtkPolyData *ParseGeometryData(vtkXMLDataElement *, bool &);
  int ParseGeometry(vtkXMLDataElement *);
  int ParseModelledGeometry(vtkXMLDataElement *);
  int ParseDimensions(vtkXMLDataElement *, const char *, int &);
  int ParseField(vtkXMLDataElement *, xmlField &);
  int ParseBoundaryConditions(vtkXMLDataElement *);
  int ParseConditions(vtkXMLDataElement *);
  int ParseSimulationInputData(vtkXMLDataElement *);
  int ParseXYZFile(vtkXMLDataElement *);

  // Field descriptions
  xmlBoundaries *Boundaries;

  // Path to the main XML file
  vtkStdString *Path;
};
